/* Generated by wayland-scanner 1.18.0 */

#ifndef PHOSH_CLIENT_PROTOCOL_H
#define PHOSH_CLIENT_PROTOCOL_H

#include <stdint.h>
#include <stddef.h>
#include "wayland-client.h"

#ifdef  __cplusplus
extern "C" {
#endif

/**
 * @page page_phosh The phosh protocol
 * @section page_ifaces_phosh Interfaces
 * - @subpage page_iface_phosh_private - Phone shell extensions
 * - @subpage page_iface_phosh_private_xdg_switcher - Interface to list and raise xdg surfaces
 */
struct phosh_private;
struct phosh_private_xdg_switcher;
struct wl_surface;

/**
 * @page page_iface_phosh_private phosh_private
 * @section page_iface_phosh_private_desc Description
 *
 * Private protocol between phosh and the compositor.
 * @section page_iface_phosh_private_api API
 * See @ref iface_phosh_private.
 */
/**
 * @defgroup iface_phosh_private The phosh_private interface
 *
 * Private protocol between phosh and the compositor.
 */
extern const struct wl_interface phosh_private_interface;
/**
 * @page page_iface_phosh_private_xdg_switcher phosh_private_xdg_switcher
 * @section page_iface_phosh_private_xdg_switcher_desc Description
 *
 * The interface is meant to list xdg surfaces (see the xdg-shell
 * stable wayland protocol) and to raise these surfaces to the top
 * of the window stack.
 *
 * It's up to the compositor if it only lists surfaces of the
 * xdg-shell stable protocol or also surfaces using unstable versions of
 * the xdg-shell protocol.
 * @section page_iface_phosh_private_xdg_switcher_api API
 * See @ref iface_phosh_private_xdg_switcher.
 */
/**
 * @defgroup iface_phosh_private_xdg_switcher The phosh_private_xdg_switcher interface
 *
 * The interface is meant to list xdg surfaces (see the xdg-shell
 * stable wayland protocol) and to raise these surfaces to the top
 * of the window stack.
 *
 * It's up to the compositor if it only lists surfaces of the
 * xdg-shell stable protocol or also surfaces using unstable versions of
 * the xdg-shell protocol.
 */
extern const struct wl_interface phosh_private_xdg_switcher_interface;

#ifndef PHOSH_PRIVATE_ERROR_ENUM
#define PHOSH_PRIVATE_ERROR_ENUM
enum phosh_private_error {
	/**
	 * an invalid argument was provided in a request
	 */
	PHOSH_PRIVATE_ERROR_INVALID_ARGUMENT = 0,
};
#endif /* PHOSH_PRIVATE_ERROR_ENUM */

#define PHOSH_PRIVATE_ROTATE_DISPLAY 0
#define PHOSH_PRIVATE_GET_XDG_SWITCHER 1


/**
 * @ingroup iface_phosh_private
 */
#define PHOSH_PRIVATE_ROTATE_DISPLAY_SINCE_VERSION 1
/**
 * @ingroup iface_phosh_private
 */
#define PHOSH_PRIVATE_GET_XDG_SWITCHER_SINCE_VERSION 2

/** @ingroup iface_phosh_private */
static inline void
phosh_private_set_user_data(struct phosh_private *phosh_private, void *user_data)
{
	wl_proxy_set_user_data((struct wl_proxy *) phosh_private, user_data);
}

/** @ingroup iface_phosh_private */
static inline void *
phosh_private_get_user_data(struct phosh_private *phosh_private)
{
	return wl_proxy_get_user_data((struct wl_proxy *) phosh_private);
}

static inline uint32_t
phosh_private_get_version(struct phosh_private *phosh_private)
{
	return wl_proxy_get_version((struct wl_proxy *) phosh_private);
}

/** @ingroup iface_phosh_private */
static inline void
phosh_private_destroy(struct phosh_private *phosh_private)
{
	wl_proxy_destroy((struct wl_proxy *) phosh_private);
}

/**
 * @ingroup iface_phosh_private
 *
 * Rotate the output clockwise 0, 90, 180 or 270 degree.
 */
static inline void
phosh_private_rotate_display(struct phosh_private *phosh_private, struct wl_surface *surface, uint32_t degree)
{
	wl_proxy_marshal((struct wl_proxy *) phosh_private,
			 PHOSH_PRIVATE_ROTATE_DISPLAY, surface, degree);
}

/**
 * @ingroup iface_phosh_private
 */
static inline struct phosh_private_xdg_switcher *
phosh_private_get_xdg_switcher(struct phosh_private *phosh_private)
{
	struct wl_proxy *id;

	id = wl_proxy_marshal_constructor((struct wl_proxy *) phosh_private,
			 PHOSH_PRIVATE_GET_XDG_SWITCHER, &phosh_private_xdg_switcher_interface, NULL);

	return (struct phosh_private_xdg_switcher *) id;
}

#ifndef PHOSH_PRIVATE_XDG_SWITCHER_ERROR_ENUM
#define PHOSH_PRIVATE_XDG_SWITCHER_ERROR_ENUM
enum phosh_private_xdg_switcher_error {
	/**
	 * an invalid argument was provided in a request
	 */
	PHOSH_PRIVATE_XDG_SWITCHER_ERROR_INVALID_ARGUMENT = 0,
};
#endif /* PHOSH_PRIVATE_XDG_SWITCHER_ERROR_ENUM */

/**
 * @ingroup iface_phosh_private_xdg_switcher
 * @struct phosh_private_xdg_switcher_listener
 */
struct phosh_private_xdg_switcher_listener {
	/**
	 * report an xdg surface
	 *
	 * 
	 * @param app_id the app_id of the xdg surface
	 * @param title the title of the xdg surface
	 * @since 2
	 */
	void (*xdg_surface)(void *data,
			    struct phosh_private_xdg_switcher *phosh_private_xdg_switcher,
			    const char *app_id,
			    const char *title);
	/**
	 * all xdg surfaces were sent
	 *
	 * 
	 * @since 2
	 */
	void (*list_xdg_surfaces_done)(void *data,
				       struct phosh_private_xdg_switcher *phosh_private_xdg_switcher);
};

/**
 * @ingroup iface_phosh_private_xdg_switcher
 */
static inline int
phosh_private_xdg_switcher_add_listener(struct phosh_private_xdg_switcher *phosh_private_xdg_switcher,
					const struct phosh_private_xdg_switcher_listener *listener, void *data)
{
	return wl_proxy_add_listener((struct wl_proxy *) phosh_private_xdg_switcher,
				     (void (**)(void)) listener, data);
}

#define PHOSH_PRIVATE_XDG_SWITCHER_LIST_XDG_SURFACES 0
#define PHOSH_PRIVATE_XDG_SWITCHER_DESTROY 1
#define PHOSH_PRIVATE_XDG_SWITCHER_RAISE_XDG_SURFACE 2
#define PHOSH_PRIVATE_XDG_SWITCHER_CLOSE_XDG_SURFACE 3

/**
 * @ingroup iface_phosh_private_xdg_switcher
 */
#define PHOSH_PRIVATE_XDG_SWITCHER_XDG_SURFACE_SINCE_VERSION 2
/**
 * @ingroup iface_phosh_private_xdg_switcher
 */
#define PHOSH_PRIVATE_XDG_SWITCHER_LIST_XDG_SURFACES_DONE_SINCE_VERSION 2

/**
 * @ingroup iface_phosh_private_xdg_switcher
 */
#define PHOSH_PRIVATE_XDG_SWITCHER_LIST_XDG_SURFACES_SINCE_VERSION 2
/**
 * @ingroup iface_phosh_private_xdg_switcher
 */
#define PHOSH_PRIVATE_XDG_SWITCHER_DESTROY_SINCE_VERSION 2
/**
 * @ingroup iface_phosh_private_xdg_switcher
 */
#define PHOSH_PRIVATE_XDG_SWITCHER_RAISE_XDG_SURFACE_SINCE_VERSION 2
/**
 * @ingroup iface_phosh_private_xdg_switcher
 */
#define PHOSH_PRIVATE_XDG_SWITCHER_CLOSE_XDG_SURFACE_SINCE_VERSION 3

/** @ingroup iface_phosh_private_xdg_switcher */
static inline void
phosh_private_xdg_switcher_set_user_data(struct phosh_private_xdg_switcher *phosh_private_xdg_switcher, void *user_data)
{
	wl_proxy_set_user_data((struct wl_proxy *) phosh_private_xdg_switcher, user_data);
}

/** @ingroup iface_phosh_private_xdg_switcher */
static inline void *
phosh_private_xdg_switcher_get_user_data(struct phosh_private_xdg_switcher *phosh_private_xdg_switcher)
{
	return wl_proxy_get_user_data((struct wl_proxy *) phosh_private_xdg_switcher);
}

static inline uint32_t
phosh_private_xdg_switcher_get_version(struct phosh_private_xdg_switcher *phosh_private_xdg_switcher)
{
	return wl_proxy_get_version((struct wl_proxy *) phosh_private_xdg_switcher);
}

/**
 * @ingroup iface_phosh_private_xdg_switcher
 *
 * Request to list xdg shell toplevels.
 */
static inline void
phosh_private_xdg_switcher_list_xdg_surfaces(struct phosh_private_xdg_switcher *phosh_private_xdg_switcher)
{
	wl_proxy_marshal((struct wl_proxy *) phosh_private_xdg_switcher,
			 PHOSH_PRIVATE_XDG_SWITCHER_LIST_XDG_SURFACES);
}

/**
 * @ingroup iface_phosh_private_xdg_switcher
 */
static inline void
phosh_private_xdg_switcher_destroy(struct phosh_private_xdg_switcher *phosh_private_xdg_switcher)
{
	wl_proxy_marshal((struct wl_proxy *) phosh_private_xdg_switcher,
			 PHOSH_PRIVATE_XDG_SWITCHER_DESTROY);

	wl_proxy_destroy((struct wl_proxy *) phosh_private_xdg_switcher);
}

/**
 * @ingroup iface_phosh_private_xdg_switcher
 *
 */
static inline void
phosh_private_xdg_switcher_raise_xdg_surface(struct phosh_private_xdg_switcher *phosh_private_xdg_switcher, const char *app_id, const char *title)
{
	wl_proxy_marshal((struct wl_proxy *) phosh_private_xdg_switcher,
			 PHOSH_PRIVATE_XDG_SWITCHER_RAISE_XDG_SURFACE, app_id, title);
}

/**
 * @ingroup iface_phosh_private_xdg_switcher
 *
 */
static inline void
phosh_private_xdg_switcher_close_xdg_surface(struct phosh_private_xdg_switcher *phosh_private_xdg_switcher, const char *app_id, const char *title)
{
	wl_proxy_marshal((struct wl_proxy *) phosh_private_xdg_switcher,
			 PHOSH_PRIVATE_XDG_SWITCHER_CLOSE_XDG_SURFACE, app_id, title);
}

#ifdef  __cplusplus
}
#endif

#endif
